@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 #    test.pl: simple sample program to test the PCSC Perl wrapper
-#    Copyright (C) 2001  Lionel Victor, 2003 Ludovic Rousseau
+#    Copyright (C) 2001  Lionel Victor, 2003,2006 Ludovic Rousseau
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,12 +17,14 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: test.pl,v 1.13 2006-08-12 17:35:49 rousseau Exp $
+# $Id: test.pl,v 1.14 2006-12-09 13:04:26 rousseau Exp $
 
-use ExtUtils::testlib;
+use Test::More;
 use Chipcard::PCSC;
 use Chipcard::PCSC::Card;
 
+plan 'no_plan';
+
 use warnings;
 use strict;
 
@@ -37,21 +39,22 @@ my $RecvData;
 my $sw;
 
 #-------------------------------------------------------------------------------
-print "Getting context:\n";
+diag("Getting context:");
 $hContext = new Chipcard::PCSC();
 die ("Can't create the pcsc object: $Chipcard::PCSC::errno\n") unless (defined $hContext);
-print '.'x40 . " OK\n";
+ok(defined $hContext, "new Chipcard::PCSC()");
 
 #-------------------------------------------------------------------------------
-print "Retrieving readers'list:\n";
+diag("Retrieving readers'list:");
 @ReadersList = $hContext->ListReaders ();
 die ("Can't get readers' list: $Chipcard::PCSC::errno\n") unless (defined($ReadersList[0]));
 $, = "\n  ";
 $" = "\n  ";
-print "  @ReadersList\n" . '.'x40 . " OK\n";
+ok(defined($ReadersList[0]), "\$hContext->ListReaders ()");
+diag(@ReadersList);
 
 #-------------------------------------------------------------------------------
-print "Getting status change:\n";
+diag("Getting status change:");
 my (@readers_states, $reader_state, $timeout, $event_state);
 # create the list or readers to watch
 map { push @readers_states, ({'reader_name'=>"$_"}) } @ReadersList;
@@ -60,15 +63,19 @@ map { push @readers_states, ({'reader_name'=>"$_"}) } @ReadersList;
 
 for my $i (0..$#readers_states)
 {
-	print "reader: " . $readers_states[$i]{'reader_name'} . "\n";
-	print "  ATR: " .
-	Chipcard::PCSC::array_to_ascii($readers_states[$i]{'ATR'}) .  "\n" if (defined $readers_states[$i]{'ATR'});
-	print "  state:\n";
+	diag("reader: " . $readers_states[$i]{'reader_name'});
+	diag("  ATR: " . Chipcard::PCSC::array_to_ascii($readers_states[$i]{'ATR'}))
+		if (defined $readers_states[$i]{'ATR'});
+	diag("  state:");
 	$event_state = $readers_states[$i]{'event_state'};
-	print "    state changed\n" if ($event_state & $Chipcard::PCSC::SCARD_STATE_CHANGED);
-	print "    card present\n" if ($event_state & $Chipcard::PCSC::SCARD_STATE_PRESENT);
-	print "    card absent\n" if ($event_state & $Chipcard::PCSC::SCARD_STATE_EMPTY);
-	print "    card mute\n" if ($event_state & $Chipcard::PCSC::SCARD_STATE_MUTE);
+	diag("    state changed")
+		if ($event_state & $Chipcard::PCSC::SCARD_STATE_CHANGED);
+	diag("    card present")
+		if ($event_state & $Chipcard::PCSC::SCARD_STATE_PRESENT);
+	diag("    card absent")
+		if ($event_state & $Chipcard::PCSC::SCARD_STATE_EMPTY);
+	diag("    card mute")
+		if ($event_state & $Chipcard::PCSC::SCARD_STATE_MUTE);
 
 	$readers_states[$i]{'current_state'} = $event_state;
 }
@@ -77,110 +84,97 @@ if (! ($readers_states[0]{'event_state'} &
 		$Chipcard::PCSC::SCARD_STATE_PRESENT))
 {
 	$timeout = 10 * 1000;	# 10 seconds
-	print "Insert a card in the first reader please (timeout in $timeout ms)\n";
+	diag("Insert a card in the first reader please (timeout in $timeout ms)");
 	@StatusResult = $hContext->GetStatusChange(\@readers_states, $timeout);
 }
-print '.'x40 . " OK\n";
 
 #-------------------------------------------------------------------------------
-print "Connecting to the card:\n";
+diag("Connecting to the card:");
 $hCard = new Chipcard::PCSC::Card ($hContext);
 die ("Can't create the reader object: $Chipcard::PCSC::errno\n") unless (defined($hCard));
 
 $tmpVal = $hCard->Connect($ReadersList[0], $Chipcard::PCSC::SCARD_SHARE_SHARED);
 unless ($tmpVal) {
 	# Try to reconnect and reset if connect fails
-	print "Connect failed: trying to reset the card:\n";
+	diag("Connect failed: trying to reset the card:");
 	$tmpVal = $hCard->Reconnect ($Chipcard::PCSC::SCARD_SHARE_SHARED, $Chipcard::PCSC::SCARD_PROTOCOL_T0, $Chipcard::PCSC::SCARD_RESET_CARD);
 	die ("Can't reconnect to the reader '$ReadersList[0]': $Chipcard::PCSC::errno\n") unless ($tmpVal);
 }
-die ("Can't understand the current protocol: $hCard->{dwProtocol}\n")
-	unless ($hCard->{dwProtocol}==$Chipcard::PCSC::SCARD_PROTOCOL_T0 ||
-            $hCard->{dwProtocol}==$Chipcard::PCSC::SCARD_PROTOCOL_T1 ||
-	        $hCard->{dwProtocol}==$Chipcard::PCSC::SCARD_PROTOCOL_RAW);
-print '.'x40 . " OK\n";
+ok($hCard->{dwProtocol}==$Chipcard::PCSC::SCARD_PROTOCOL_T0 ||
+	$hCard->{dwProtocol}==$Chipcard::PCSC::SCARD_PROTOCOL_T1 ||
+	$hCard->{dwProtocol}==$Chipcard::PCSC::SCARD_PROTOCOL_RAW,
+	"Can understand the current protocol: $hCard->{dwProtocol}");
 
 #-------------------------------------------------------------------------------
-print ("Setting up timeout value:\n");
-die ("Can't set timeout: $Chipcard::PCSC::errno\n") unless ($hContext->SetTimeout (50));
-print '.'x40 . " OK\n";
-
-#-------------------------------------------------------------------------------
-print "Getting status:\n";
+diag("Getting status:");
 @StatusResult = $hCard->Status();
 die ("Can't get status: $Chipcard::PCSC::errno\n") unless ($StatusResult[0]);
-print "Reader name is $StatusResult[0]\n";
-print "State: $StatusResult[1]\n";
-print "Current protocol: $StatusResult[2]\n";
-print "ATR: " . Chipcard::PCSC::array_to_ascii ($StatusResult[3]) . "\n";
-print '.'x40 . " OK\n";
+diag("Reader name is $StatusResult[0]");
+diag("State: $StatusResult[1]");
+diag("Current protocol: $StatusResult[2]");
+diag("ATR: " . Chipcard::PCSC::array_to_ascii ($StatusResult[3]));
 
 #-------------------------------------------------------------------------------
-print ("Initiating transaction:\n");
+diag("Initiating transaction:");
 die ("Can't initiate transaction: $Chipcard::PCSC::errno\n") unless ($hCard->BeginTransaction());
-print '.'x40 . " OK\n";
+diag($hCard->BeginTransaction(), "\$hCard->BeginTransaction()");
 
 #-------------------------------------------------------------------------------
-#sleep (13);
-
-print ("Exchanging data:\n");
+diag("Exchanging data:");
 $SendData = Chipcard::PCSC::ascii_to_array ("00 A4 01 00 02 01 00");
 $RecvData = $hCard->Transmit($SendData);
 die ("Can't transmit data: $Chipcard::PCSC::errno") unless (defined ($RecvData));
 
-print "  Send -> " . Chipcard::PCSC::array_to_ascii ($SendData) . "\n";
-print "  Recv <- " . Chipcard::PCSC::array_to_ascii ($RecvData) . "\n";
-print '.'x40 . " OK\n";
-# sleep (3);
+diag("  Send -> " . Chipcard::PCSC::array_to_ascii ($SendData));
+diag("  Recv <- " . Chipcard::PCSC::array_to_ascii ($RecvData));
 
 #-------------------------------------------------------------------------------
-print "TransmitWithCheck:\n";
+diag("TransmitWithCheck:");
 $SendData = "00 A4 00 00 02 3F 00";	# select DF 3F 00
 # wait for ".. .." since we the SW will depend on the inserted card
 ($sw, $RecvData) = $hCard->TransmitWithCheck($SendData, ".. ..", 1);
 warn "TransmitWithCheck: $Chipcard::PCSC::Card::Error" unless defined $sw;
+ok(defined $sw, "\$hCard->TransmitWithCheck");
 
-print "  Send -> $SendData\n";
-print "  Recv <- $RecvData (SW: $sw)\n";
-print '.'x40 . " OK\n";
+diag("  Send -> $SendData");
+diag("  Recv <- $RecvData (SW: $sw)");
 
 #-------------------------------------------------------------------------------
-print "ISO7816Error:\n";
-print "$sw: " . &Chipcard::PCSC::Card::ISO7816Error($sw) . "\n";
-print '.'x40 . " OK\n";
+diag("ISO7816Error:");
+diag("$sw: " . &Chipcard::PCSC::Card::ISO7816Error($sw));
 
 #-------------------------------------------------------------------------------
 # This test is commented since it is reader/driver specific and may do bad
 # things for another reader. Reader your reader and driver
 # specifications to know what data to use.
 #
-#print "Control\n";
+#diag("Control");
 #$SendData = Chipcard::PCSC::ascii_to_array ("02");
 #$RecvData = $hCard->Control(0x42000001, $SendData);
 #die ("Can't Control data: $Chipcard::PCSC::errno") unless (defined ($RecvData));
 #
-#print "  Send -> " . Chipcard::PCSC::array_to_ascii ($SendData) . "\n";
-#print "  Recv <- " . Chipcard::PCSC::array_to_ascii ($RecvData) . "\n";
-#print '.'x40 . " OK\n";
+#diag("  Send -> " . Chipcard::PCSC::array_to_ascii ($SendData));
+#diag("  Recv <- " . Chipcard::PCSC::array_to_ascii ($RecvData));
 
 #-------------------------------------------------------------------------------
-print ("Ending transaction:\n");
+diag("Ending transaction:");
 die ("Can't terminate transaction: $Chipcard::PCSC::errno\n") unless ($hCard->EndTransaction($Chipcard::PCSC::SCARD_LEAVE_CARD));
-print '.'x40 . " OK\n";
+ok($hCard->EndTransaction($Chipcard::PCSC::SCARD_LEAVE_CARD),
+	"\$hCard->EndTransaction($Chipcard::PCSC::SCARD_LEAVE_CARD)");
 
 #-------------------------------------------------------------------------------
-print "Disconnecting the card:\n";
+diag("Disconnecting the card:");
 $tmpVal = $hCard->Disconnect($Chipcard::PCSC::SCARD_LEAVE_CARD);
 die ("Can't disconnect the Chipcard::PCSC object: $Chipcard::PCSC::errno\n") unless $tmpVal;
-print '.'x40 . " OK\n";
+ok($tmpVal, "\$hCard->Disconnect");
+
 #-------------------------------------------------------------------------------
-print "Closing card object:\n";
+diag("Closing card object:");
 $hCard = undef;
-print '.'x40 . " OK\n";
+
 #-------------------------------------------------------------------------------
-print "Closing context:\n";
+diag("Closing context:");
 $hContext = undef;
-#print '.'x40 . " OK\n";
 
 # End of File #
 
